@@ -1,14 +1,46 @@
-# Copyright (C) 2010-2013 by Carnegie Mellon University
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License, as published by
-# the Free Software Foundation, under the terms pursuant to Version 2,
-# June 1991.
-#
-# This program is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-# General Public License for more details.
+# Use of the Net-Silk library and related source code is subject to the
+# terms of the following licenses:
+# 
+# GNU Public License (GPL) Rights pursuant to Version 2, June 1991
+# Government Purpose License Rights (GPLR) pursuant to DFARS 252.227.7013
+# 
+# NO WARRANTY
+# 
+# ANY INFORMATION, MATERIALS, SERVICES, INTELLECTUAL PROPERTY OR OTHER 
+# PROPERTY OR RIGHTS GRANTED OR PROVIDED BY CARNEGIE MELLON UNIVERSITY 
+# PURSUANT TO THIS LICENSE (HEREINAFTER THE "DELIVERABLES") ARE ON AN 
+# "AS-IS" BASIS. CARNEGIE MELLON UNIVERSITY MAKES NO WARRANTIES OF ANY 
+# KIND, EITHER EXPRESS OR IMPLIED AS TO ANY MATTER INCLUDING, BUT NOT 
+# LIMITED TO, WARRANTY OF FITNESS FOR A PARTICULAR PURPOSE, 
+# MERCHANTABILITY, INFORMATIONAL CONTENT, NONINFRINGEMENT, OR ERROR-FREE 
+# OPERATION. CARNEGIE MELLON UNIVERSITY SHALL NOT BE LIABLE FOR INDIRECT, 
+# SPECIAL OR CONSEQUENTIAL DAMAGES, SUCH AS LOSS OF PROFITS OR INABILITY 
+# TO USE SAID INTELLECTUAL PROPERTY, UNDER THIS LICENSE, REGARDLESS OF 
+# WHETHER SUCH PARTY WAS AWARE OF THE POSSIBILITY OF SUCH DAMAGES. 
+# LICENSEE AGREES THAT IT WILL NOT MAKE ANY WARRANTY ON BEHALF OF 
+# CARNEGIE MELLON UNIVERSITY, EXPRESS OR IMPLIED, TO ANY PERSON 
+# CONCERNING THE APPLICATION OF OR THE RESULTS TO BE OBTAINED WITH THE 
+# DELIVERABLES UNDER THIS LICENSE.
+# 
+# Licensee hereby agrees to defend, indemnify, and hold harmless Carnegie 
+# Mellon University, its trustees, officers, employees, and agents from 
+# all claims or demands made against them (and any related losses, 
+# expenses, or attorney's fees) arising out of, or relating to Licensee's 
+# and/or its sub licensees' negligent use or willful misuse of or 
+# negligent conduct or willful misconduct regarding the Software, 
+# facilities, or other rights or assistance granted by Carnegie Mellon 
+# University under this License, including, but not limited to, any 
+# claims of product liability, personal injury, death, damage to 
+# property, or violation of any laws or regulations.
+# 
+# Carnegie Mellon University Software Engineering Institute authored 
+# documents are sponsored by the U.S. Department of Defense under 
+# Contract FA8721-05-C-0003. Carnegie Mellon University retains 
+# copyrights in all material produced under this contract. The U.S. 
+# Government retains a non-exclusive, royalty-free license to publish or 
+# reproduce these documents, or allow others to do so, for U.S. 
+# Government purposes only pursuant to the copyright license under the 
+# contract clause at 252.227.7013.
 
 package Net::Nmsg;
 
@@ -29,7 +61,7 @@ use base qw( Exporter DynaLoader );
 sub dl_load_flags { 0x01 } # global option
 
 BEGIN {
-  $VERSION = '0.12';
+  $VERSION = '0.13';
   bootstrap Net::Nmsg $VERSION;
 }
 
@@ -38,8 +70,8 @@ my($Debug, $Autoclose);
 sub DEBUG     { @_ ? set_debug    ($Debug     = shift) : $Debug     }
 sub AUTOCLOSE { @_ ? set_autoclose($Autoclose = shift) : $Autoclose }
 
-DEBUG(0);
-AUTOCLOSE(0);
+DEBUG(int($ENV{NET_NMSG_DEBUG} || 0));
+AUTOCLOSE(int($ENV{NET_NMSG_AUTOCLOSE} || 0));
 
 _nmsg_init_lib();
 
@@ -386,18 +418,18 @@ The pcap library can be downloaded from: http://www.tcpdump.org/
 
 Matthew Sisk, E<lt>sisk@cert.orgE<gt>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT & LICENSE
 
-Copyright (C) 2010-2014 by Carnegie Mellon University
+Copyright (C) 2010-2015 by Carnegie Mellon University
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License, as published by
-the Free Software Foundation, under the terms pursuant to Version 2,
-June 1991.
+Use of the Net-Silk library and related source code is subject to the
+terms of the following licenses:
 
-This program is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
-Public License for more details.
+GNU Public License (GPL) Rights pursuant to Version 2, June 1991
+Government Purpose License Rights (GPLR) pursuant to DFARS 252.227.7013
+
+NO WARRANTY
+
+See GPL.txt and LICENSE.txt for more details.
 
 =cut
